@@ -5,31 +5,31 @@
 include "scripting/richtext_scenarios.lua"
 
 function jundlina(title, text)
-   return speech("map:princess.png", "2F9131", title, text)
+   return speech("map:princess.png", styles.color("campaign_atl_jundlina"), title, text)
 end
 function loftomor(text)
-   return speech("map:loftomor.png", "FDD53D", "Loftomor", text)
+   return speech("map:loftomor.png", styles.color("campaign_atl_loftomor"), "Loftomor", text)
 end
 function sidolus(title, text)
-   return speech("map:sidolus.png", "FF1A30", title, text)
+   return speech("map:sidolus.png", styles.color("campaign_atl_sidolus"), title, text)
 end
 function colionder(text)
-   return speech("map:colionder.png", "33A9FD", "Colionder", text)
+   return speech("map:colionder.png", styles.color("campaign_atl_colionder"), "Colionder", text)
 end
 function opol(text)
-   return speech("map:opol.png", "FF3FFB", "Opol", text)
+   return speech("map:opol.png", styles.color("campaign_atl_opol"), "Opol", text)
 end
 function ostur(text)
-   return speech("map:ostur.png", "375FFC", "Ostur", text)
+   return speech("map:ostur.png", styles.color("campaign_atl_ostur"), "Ostur", text)
 end
 function kalitath(text)
-   return speech("map:kalitath.png", "FF0000", "Kalitath", text)
+   return speech("map:kalitath.png", styles.color("campaign_atl_kalitath"), "Kalitath", text)
 end
 function current_leader(lead, text)
    if lead == 1 then
-      return speech("map:princess.png", "2F9131", name[lead], text)
+      return speech("map:princess.png", styles.color("campaign_atl_jundlina"), name[lead], text)
    else
-      return speech("map:sidolus.png", "FF1A30", name[lead], text)
+      return speech("map:sidolus.png", styles.color("campaign_atl_sidolus"), name[lead], text)
    end
 end
 
@@ -197,7 +197,7 @@ initial_messages = {
          _([[And one failed the test: the last days of loading was done in chaos and without much planning and so one of our ships ended up carrying most of the heavy wares in our possession.]])
          .. paragraphdivider() ..
          -- TRANSLATORS: Jundlina - Diary
-         _([[The heavy weight plus the strong current was too much for the ship and it was pulled below the sea level by Lutas’ forces and we lost most men and all wares it carried.]])
+         _([[The heavy weight plus the strong current was too much for the ship and it was pulled below the sea level by Lutas’s forces and we lost most men and all wares it carried.]])
          .. paragraphdivider() ..
          -- TRANSLATORS: Jundlina - Diary
          _([[All of us were fiercely afraid. We expected the other ships to be sunken as well, but they persisted. We escaped the island and began our smooth sailing to other coasts.]])),
@@ -573,7 +573,7 @@ princess_back = {
       title = _("Jundlina Explains"),
       body = jundlina(_("Jundlina"),
          -- TRANSLATORS: Jundlina
-         _([[Sidolus, they did not let me go. I met our scout and he managed to sneak me out, as I realized they still kept me hostage after I expressed some concerns about our previous agreement. So we need to settle the barbarian issue now and forever on this island. There is no other way to live here in peace than to defeat them.]]))
+         _([[Sidolus, they did not let me go. I met our scout and he managed to sneak me out, as I realized they still kept me hostage after I expressed some concerns about our previous agreement. So we need to settle the Barbarian issue now and forever on this island. There is no other way to live here in peace than to defeat them.]]))
          .. new_objectives(obj_defeat_kalitath),
    }
 }
