@@ -8,6 +8,8 @@
 include "scripting/richtext.lua"
 include "scripting/help.lua"
 
+local icon_gap = styles.get_size("editor_tooltip_icon_gap")
+
 return {
    func = function(tree_name)
       push_textdomain("widelands_editor")
@@ -18,8 +20,9 @@ return {
 
       for k,v in ipairs(terrain_list) do
          if v.probability > 0.19 then
-            result = result .. img(v.terrain.representative_image) ..space(2) ..
-                (_("%2.1f%%")):bformat(100 * v.probability) .. space(12)
+            result = result .. div("width=33%", p("valign=center",
+               img(v.terrain.representative_image) .. space(icon_gap) ..
+               _("%2.1f%%"):bformat(100 * v.probability)))
             -- We have space for 3 terrains per row in tooltips
             if k % 3 == 0 then
                result = result .. "<br>"
@@ -28,7 +31,9 @@ return {
       end
 
       -- TRANSLATORS: A header in the editor help. Terrains preferred by a type of tree.
-      result = vspace(3) .. h3(_("Preferred terrains")) .. vspace(3) .. p(result)
+      result = h3(_("Preferred terrains")) ..
+               vspace(styles.get_size("help_terrain_tree_header_space_after")) ..
+               p(result)
       pop_textdomain()
       return {
          text = result
