@@ -1,11 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname (__file__)
+local dirname = path.dirname (__file__)
 
 wl.Descriptions():new_immovable_type {
    name = "pond_dry",
    -- TRANSLATORS: This is an immovable name used in lists of immovables
    descname = pgettext ("immovable", "Dry Pond"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    size = "small",
    programs = {
@@ -22,8 +23,6 @@ wl.Descriptions():new_immovable_type {
    },
    animations = {
       idle = {
-         directory = dirname,
-         basename = "idle",
          hotspot = {8, 5}
       }
    }
