@@ -1,11 +1,11 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__) .. "../"
+local dirname = path.dirname(__file__) .. "../"
 
 wl.Descriptions():new_immovable_type {
    name = "amazons_resi_stones_1",
    -- TRANSLATORS: This is a resource name used in lists of resources
-   descname = pgettext("resource_indicator", "Some Granite"),
+   descname = pgettext("resource_indicator", "Some Quartz"),
    icon = dirname .. "pics/stones_1_1.png",
    programs = {
       main = {
