@@ -1,11 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname (__file__)
+local dirname = path.dirname (__file__)
 
 wl.Descriptions():new_worker_type {
    name = "frisians_beekeeper",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext ("frisians_worker", "Beekeeper"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    vision_range = 2,
 
@@ -15,6 +16,9 @@ wl.Descriptions():new_worker_type {
 
    programs = {
       bees = {
+         -- steps from building to flowering plant: 2-8
+         -- min. worker time: 2 * 2 * 1.8 + 10 = 17.2 sec
+         -- max. worker time: 2 * 8 * 1.8 + 10 = 38.8 sec
          "findobject=attrib:flowering radius:5",
          "walk=object",
          "animate=beeswarm duration:10s",
@@ -27,8 +31,6 @@ wl.Descriptions():new_worker_type {
 
    spritesheets = {
       walk = {
-         directory = dirname,
-         basename = "walk",
          fps = 15,
          frames = 10,
          columns = 5,
@@ -37,8 +39,6 @@ wl.Descriptions():new_worker_type {
          hotspot = {11, 24}
       },
       walkload = {
-         directory = dirname,
-         basename = "walkload",
          fps = 15,
          frames = 10,
          columns = 5,
@@ -47,8 +47,6 @@ wl.Descriptions():new_worker_type {
          hotspot = {10, 26}
       },
       beeswarm = {
-         directory = dirname,
-         basename = "beeswarm",
          fps = 50,
          frames = 100,
          columns = 5,
@@ -58,8 +56,6 @@ wl.Descriptions():new_worker_type {
    },
    animations = {
       idle = {
-         directory = dirname,
-         basename = "idle",
          hotspot = {8, 23}
       },
    },
