@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 by the Widelands Development Team
+ * Copyright (C) 2020-2025 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -64,11 +64,11 @@ namespace AddOns {
  * repo (widelands/wl_addons_server) in `wl.server.Command`.
  */
 
-constexpr unsigned kCurrentProtocolVersion = 7;
-static const std::string kCmdList = "2:CMD_LIST";
-static const std::string kCmdInfo = "2:CMD_INFO";
+constexpr unsigned kCurrentProtocolVersion = 8;
+static const std::string kCmdList = "3:CMD_LIST";
+static const std::string kCmdInfo = "3:CMD_INFO";
 static const std::string kCmdDownload = "1:CMD_DOWNLOAD";
-static const std::string kCmdI18N = "1:CMD_I18N";
+static const std::string kCmdI18N = "2:CMD_I18N";
 static const std::string kCmdScreenshot = "1:CMD_SCREENSHOT";
 static const std::string kCmdVote = "1:CMD_VOTE";
 static const std::string kCmdGetVote = "1:CMD_GET_VOTE";
@@ -100,16 +100,33 @@ inline int portable_read(const int socket, char* buffer, const size_t length) {
 #endif
 }
 
-inline void check_string_validity(const std::string& str) {
+[[nodiscard]] inline bool name_valid(const std::string& filename) {
+	// Requirements are defined and enforced by the server.
+	return !filename.empty() && filename.size() <= 80 &&
+	       filename.find_first_not_of("ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+	                                  "abcdefghijklmnopqrstuvwxyz"
+	                                  "0123456789._-") == std::string::npos &&
+	       filename.find("..") == std::string::npos;
+}
+}  // namespace
+
+void NetAddons::throw_warning(const std::string& message) const {
+	if (last_error_message_.empty()) {
+		throw WLWarning("", "%s", message.c_str());
+	}
+	throw WLWarning("", "%s\n\nRecent errors:\n%s", message.c_str(), last_error_message_.c_str());
+}
+
+void NetAddons::check_string_validity(const std::string& str) {
 	if (contains(str, " ")) {
-		throw WLWarning("", "String '%s' may not contain whitespaces", str.c_str());
+		throw_warning(format("String '%s' may not contain whitespaces", str.c_str()));
 	}
 	if (contains(str, "\n")) {
-		throw WLWarning("", "String '%s' may not contain newlines", str.c_str());
+		throw_warning(format("String '%s' may not contain newlines", str.c_str()));
 	}
 }
 
-void check_checksum(const std::string& path, const std::string& checksum) {
+void NetAddons::check_checksum(const std::string& path, const std::string& checksum) {
 	FileRead fr;
 	fr.open(*g_fs, path);
 	const size_t bytes = fr.get_size();
@@ -117,33 +134,40 @@ void check_checksum(const std::string& path, const std::string& checksum) {
 	fr.data_complete(complete.get(), bytes);
 	const std::string md5 = crypto::md5_str(complete.get(), bytes);
 	if (checksum != md5) {
-		throw WLWarning("", "Downloaded file '%s': Checksum mismatch, found %s, expected %s",
-		                path.c_str(), md5.c_str(), checksum.c_str());
+		throw_warning(format("Downloaded file '%s': Checksum mismatch, found %s, expected %s",
+		                     path.c_str(), md5.c_str(), checksum.c_str()));
 	}
 }
 
-size_t gather_addon_content(const std::string& current_dir,
-                            const std::string& prefix,
-                            std::map<std::string, std::set<std::string>>& result) {
+size_t NetAddons::gather_addon_content(const std::string& current_dir,
+                                       const std::string& prefix,
+                                       std::map<std::string, std::set<std::string>>& result,
+                                       std::set<std::string>& invalid_names) {
 	result[prefix] = {};
 	size_t nr_files = 0;
 	for (const std::string& f : g_fs->list_directory(current_dir)) {
-		if (g_fs->is_directory(f)) {
-			std::string str = prefix;
-			if (!str.empty()) {
-				str += FileSystem::file_separator();
+		const std::string fname = FileSystem::fs_filename(f.c_str());
+		if (!fname.empty() && fname.front() != '.') {  // Ignore hidden files
+			if (!name_valid(fname)) {
+				invalid_names.insert(f /* check the filename but display with full path */);
+			}
+			if (g_fs->is_directory(f)) {
+				std::string str = prefix;
+				if (!str.empty()) {
+					str += FileSystem::file_separator();
+				}
+				str += fname;
+				nr_files += gather_addon_content(f, str, result, invalid_names);
+			} else {
+				result[prefix].insert(fname);
+				++nr_files;
 			}
-			str += FileSystem::fs_filename(f.c_str());
-			nr_files += gather_addon_content(f, str, result);
-		} else {
-			result[prefix].insert(FileSystem::fs_filename(f.c_str()));
-			++nr_files;
 		}
 	}
 	return nr_files;
 }
 
-void append_multiline_message(std::string& send, const std::string& message) {
+void NetAddons::append_multiline_message(std::string& send, const std::string& message) {
 	send += ' ';
 	if (message.empty()) {
 		send += "0\nENDOFSTREAM\n";
@@ -155,42 +179,10 @@ void append_multiline_message(std::string& send, const std::string& message) {
 	send += message;
 	send += "\nENDOFSTREAM\n";
 }
-}  // namespace
 
-void NetAddons::init(std::string username, std::string password) {
-	if (initialized_) {
-		// already initialized
-		return;
-	}
-	if (network_active_) {
-		throw WLWarning("", "Network is already active during init");
-	}
-
-#ifdef SIGPIPE
-	signal(SIGPIPE, SIG_IGN);  // NOLINT
-#endif
-
-	cached_remotes_ = 0;
-	if (password.empty()) {
-		username = "";
-	}
-	if (username.empty()) {
-		username = last_username_;
-	} else {
-		last_username_ = "";
-	}
-	if (password.empty()) {
-		password = last_password_;
-	} else {
-		last_password_ = "";
-	}
-	check_string_validity(username);
-
-	if ((client_socket_ = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
-		throw WLWarning("", "Unable to create socket");
-	}
-
-	constexpr uint32_t kTimeout = 4;
+void NetAddons::set_timeouts(bool suppress_timeout) {
+	timeout_was_suppressed_ = suppress_timeout;
+	const uint32_t kTimeout = suppress_timeout ? (60 * 60 * 12) : 12;
 #ifdef _WIN32
 	DWORD timeout_val = kTimeout * 1000;
 	const char* timeout_ptr = reinterpret_cast<const char*>(&timeout_val);
@@ -207,6 +199,44 @@ void NetAddons::init(std::string username, std::string password) {
 	// Set timeout of write()
 	setsockopt(client_socket_, SOL_SOCKET, SO_SNDTIMEO, &timeout_val, sizeof(timeout_val));
 #endif
+}
+
+void NetAddons::init(std::string username, std::string password) {
+	if (initialized_) {
+		// already initialized
+		return;
+	}
+	if (network_active_) {
+		throw_warning("Network is already active during init");
+	}
+
+#ifdef SIGPIPE
+	signal(SIGPIPE, SIG_IGN);  // NOLINT
+#endif
+
+	last_error_message_.clear();
+	cached_remotes_ = 0;
+	if (password.empty()) {
+		username = "";
+	}
+	if (username.empty()) {
+		username = last_username_;
+	} else {
+		last_username_ = "";
+	}
+	if (password.empty()) {
+		password = last_password_;
+	} else {
+		last_password_ = "";
+	}
+	check_string_validity(username);
+
+	client_socket_ = socket(AF_INET, SOCK_STREAM, 0);
+	if (client_socket_ < 0) {
+		throw_warning("Unable to create socket");
+	}
+
+	set_timeouts(false);
 
 	const std::string target_ip = get_config_string("addon_server_ip", "widelands.org");
 	const int target_port = get_config_int("addon_server_port", 7388);
@@ -216,8 +246,8 @@ void NetAddons::init(std::string username, std::string password) {
 		NetAddress addr;
 		// TODO(Nordfriese): inet_addr can't handle IPv6 addresses
 		if (!NetAddress::resolve_to_v4(&addr, target_ip, target_port)) {
-			throw WLWarning(
-			   "", "Unable to resolve host name and port '%s' / %d", target_ip.c_str(), target_port);
+			throw_warning(format(
+			   "Unable to resolve host name and port '%s' / %d", target_ip.c_str(), target_port));
 		}
 		std::ostringstream oss("");
 		oss << addr.ip;
@@ -225,7 +255,7 @@ void NetAddons::init(std::string username, std::string password) {
 		server.sin_port = htons(addr.port);
 	}
 	if (connect(client_socket_, reinterpret_cast<sockaddr*>(&server), sizeof(server)) < 0) {
-		throw WLWarning("", "Unable to connect to the server");
+		throw_warning("Unable to connect to the server");
 	}
 
 	std::string send = std::to_string(kCurrentProtocolVersion);
@@ -240,6 +270,7 @@ void NetAddons::init(std::string username, std::string password) {
 
 	is_admin_ = false;
 	server_descname_ = read_line();
+	websitemaps_i18n_version_ = math::to_long(read_line());
 	if (username.empty()) {
 		check_endofstream();
 	} else {
@@ -256,7 +287,7 @@ void NetAddons::init(std::string username, std::string password) {
 		if (data == "ADMIN") {
 			is_admin_ = true;
 		} else if (data != "SUCCESS") {
-			throw WLWarning("", "Expected login result, received:\n%s", data.c_str());
+			throw_warning(format("Expected login result, received:\n'%s'", data.c_str()));
 		}
 	}
 
@@ -299,6 +330,7 @@ inline void NetAddons::write_to_server(const std::string& send) {
 }
 void NetAddons::write_to_server(const char* send, const size_t length) {
 	if (portable_write(client_socket_, send, length) >= 0) {
+		SDL_Delay(50);  // Give the send buffer time to clear up before sending more data.
 		return;
 	}
 
@@ -314,14 +346,15 @@ void NetAddons::write_to_server(const char* send, const size_t length) {
 
 	if (message.empty()) {
 		if (is_uploading_addon_) {
-			throw WLWarning("",
-			                "Connection interrupted (%s). Please note that you can not upload updates "
-			                "for an add-on more often than every three days.",
-			                strerror(errno));
+			throw_warning(
+			   format("Connection interrupted (%s). Please note that you can not upload updates "
+			          "for an add-on more often than every three days.",
+			          strerror(errno)));
 		}
-		throw WLWarning("", "Connection interrupted (%s)", strerror(errno));
+		throw_warning(format("Connection interrupted (%s)", strerror(errno)));
 	}
-	throw WLWarning("", "Connection interrupted (%s). Reason: %s", strerror(errno), message.c_str());
+	throw_warning(
+	   format("Connection interrupted (%s). Reason: %s", strerror(errno), message.c_str()));
 }
 
 std::string NetAddons::read_line() const {
@@ -330,11 +363,23 @@ std::string NetAddons::read_line() const {
 	int n;
 	for (;;) {
 		n = portable_read(client_socket_, &c, 1);
+		if (n < 1) {
+			throw_warning(format("Connection interrupted (%s)", strerror(errno)));
+		}
 		if (n != 1 || c == '\n') {
 			break;
 		}
 		line += c;
 	}
+
+	if (contains(line, "WL", false) && contains(line, "Protocol", false) &&
+	    contains(line, "Exception", false)) {
+		if (!last_error_message_.empty()) {
+			last_error_message_.push_back('\n');
+		}
+		last_error_message_ += line;
+	}
+
 	return line;
 }
 
@@ -345,7 +390,7 @@ void NetAddons::read_file(const int64_t length, const std::string& out) const {
 	do {
 		int64_t l = portable_read(client_socket_, buffer.get(), length - nr_bytes_read);
 		if (l < 1) {
-			throw WLWarning("", "Connection interrupted");
+			throw_warning("Connection interrupted");
 		}
 		nr_bytes_read += l;
 		fw.data(buffer.get(), l);
@@ -356,7 +401,7 @@ void NetAddons::read_file(const int64_t length, const std::string& out) const {
 void NetAddons::check_endofstream() {
 	const std::string text = read_line();
 	if (text != "ENDOFSTREAM") {
-		throw WLWarning("", "Expected end of stream, received:\n%s", text.c_str());
+		throw_warning(format("Expected end of stream, received:\n'%s'", text.c_str()));
 	}
 }
 
@@ -365,15 +410,22 @@ void NetAddons::check_endofstream() {
 // reading or writing random leftover bytes. Create it before doing some
 // networking stuff and call `ok()` after everything has gone well.
 struct CrashGuard {
-	explicit CrashGuard(NetAddons& n, bool uses_cache = false) : net_(n) {
+	explicit CrashGuard(NetAddons& n, bool suppress_timeout, bool uses_cache = false)
+	   : net_(n), timeout_was_suppressed_(n.timeout_was_suppressed_) {
 		assert(net_.initialized_);
+
 		if (net_.network_active_) {
-			throw WLWarning("", "Network is already active");
+			net_.throw_warning("Network is already active");
 		}
 		if (!uses_cache && net_.cached_remotes_ > 0) {
-			throw WLWarning("", "Network has stale remotes cache");
+			net_.throw_warning("Network has stale remotes cache");
 		}
+
 		net_.network_active_ = true;
+
+		if (timeout_was_suppressed_ != suppress_timeout) {
+			net_.set_timeouts(suppress_timeout);
+		}
 	}
 	void ok() {
 		assert(net_.initialized_);
@@ -388,17 +440,20 @@ struct CrashGuard {
 		net_.is_uploading_addon_ = false;
 		if (!ok_) {
 			net_.quit_connection();
+		} else {
+			net_.set_timeouts(timeout_was_suppressed_);
 		}
 	}
 
 private:
 	NetAddons& net_;
 	bool ok_{false};
+	bool timeout_was_suppressed_{false};
 };
 
 std::vector<std::string> NetAddons::refresh_remotes(const bool all) {
 	init();
-	CrashGuard guard(*this);
+	CrashGuard guard(*this, false);
 
 	std::string send = kCmdList;
 	send += ' ';
@@ -421,7 +476,7 @@ std::vector<std::string> NetAddons::refresh_remotes(const bool all) {
 AddOnInfo NetAddons::fetch_one_remote(const std::string& name) {
 	check_string_validity(name);
 	init();
-	CrashGuard guard(*this, true);
+	CrashGuard guard(*this, false, true);
 	if (cached_remotes_ > 0) {
 		--cached_remotes_;
 	} else {
@@ -525,17 +580,56 @@ AddOnInfo NetAddons::fetch_one_remote(const std::string& name) {
 		g_fs->fs_unlink(path);
 	}
 
+	if (a.category == AddOnCategory::kSingleMap) {
+		a.map_file_name = read_line();
+
+		a.unlocalized_map_hint = read_line();
+		std::string localized_map_hint = read_line();
+		a.map_hint = [localized_map_hint]() { return localized_map_hint; };
+
+		a.unlocalized_map_uploader_comment = read_line();
+		std::string localized_map_uploader_comment = read_line();
+		a.map_uploader_comment = [localized_map_uploader_comment]() {
+			return localized_map_uploader_comment;
+		};
+
+		a.map_width = math::to_int(read_line());
+		a.map_height = math::to_int(read_line());
+		a.map_nr_players = math::to_int(read_line());
+		a.map_world_name = read_line();
+	}
+
 	check_endofstream();
 	guard.ok();
 	return a;
 }
 
+void NetAddons::download_map(const std::string& name, const std::string& save_as) {
+	check_string_validity(name);
+	init();
+	CrashGuard guard(*this, false);
+
+	std::string send = kCmdDownload;
+	send += ' ';
+	send += name;
+	send += '\n';
+	write_to_server(send);
+
+	const std::string checksum = read_line();
+	const int64_t length = math::to_long(read_line());
+	read_file(length, save_as);
+	check_checksum(save_as, checksum);
+
+	check_endofstream();
+	guard.ok();
+}
+
 void NetAddons::download_addon(const std::string& name,
                                const std::string& save_as,
                                const CallbackFn& progress) {
 	check_string_validity(name);
 	init();
-	CrashGuard guard(*this);
+	CrashGuard guard(*this, false);
 	{
 		std::string send = kCmdDownload;
 		send += ' ';
@@ -573,7 +667,7 @@ void NetAddons::download_addon(const std::string& name,
 				progress(relative_path, progress_state);
 				int64_t l = portable_read(client_socket_, buffer.get(), length - nr_bytes_read);
 				if (l < 1) {
-					throw WLWarning("", "Connection interrupted");
+					throw_warning("Connection interrupted");
 				}
 				nr_bytes_read += l;
 				progress_state += l;
@@ -594,7 +688,7 @@ void NetAddons::download_i18n(const std::string& name,
                               const CallbackFn& init_fn) {
 	check_string_validity(name);
 	init();
-	CrashGuard guard(*this);
+	CrashGuard guard(*this, false);
 	{
 		std::string send = kCmdI18N;
 		send += ' ';
@@ -628,7 +722,7 @@ int NetAddons::get_vote(const std::string& addon) {
 	int v;
 	try {
 		init();
-		CrashGuard guard(*this);
+		CrashGuard guard(*this, false);
 
 		std::string send = kCmdGetVote;
 		send += ' ';
@@ -656,7 +750,7 @@ void NetAddons::vote(const std::string& addon, const unsigned vote) {
 	check_string_validity(addon);
 	assert(vote <= kMaxRating);
 	init();
-	CrashGuard guard(*this);
+	CrashGuard guard(*this, false);
 	std::string send = kCmdVote;
 	send += ' ';
 	send += addon;
@@ -673,7 +767,7 @@ void NetAddons::comment(const AddOnInfo& addon,
                         const size_t* index_to_edit) {
 	check_string_validity(addon.internal_name);
 	init();
-	CrashGuard guard(*this);
+	CrashGuard guard(*this, false);
 
 	std::string send;
 	if (index_to_edit == nullptr) {
@@ -698,11 +792,11 @@ void NetAddons::admin_action(const AdminAction a,
                              const AddOnInfo& addon,
                              const std::string& value) {
 	if (!is_admin()) {
-		throw WLWarning("", "Only admins can send admin actions");
+		throw_warning("Only admins can send admin actions");
 	}
 	check_string_validity(addon.internal_name);
 	init();
-	CrashGuard guard(*this);
+	CrashGuard guard(*this, true);
 
 	std::string send;
 	switch (a) {
@@ -721,6 +815,8 @@ void NetAddons::admin_action(const AdminAction a,
 	case AdminAction::kDelete:
 		send = kCmdAdminDelete;
 		break;
+	default:
+		NEVER_HERE();
 	}
 	send += ' ';
 	send += addon.internal_name;
@@ -756,11 +852,15 @@ void NetAddons::upload_addon(const std::string& name,
 		std::string dir = kAddOnDir;
 		dir += FileSystem::file_separator();
 		dir += name;
-		init_fn("", gather_addon_content(dir, "", content));
+		std::set<std::string> invalid_names;
+		init_fn("", gather_addon_content(dir, "", content, invalid_names));
+		if (!invalid_names.empty()) {
+			throw IllegalFilenamesException(invalid_names);
+		}
 	}
 
 	is_uploading_addon_ = true;
-	CrashGuard guard(*this);
+	CrashGuard guard(*this, true);
 	std::string send = kCmdSubmit;
 	send += ' ';
 	send += name;
@@ -792,7 +892,7 @@ void NetAddons::upload_addon(const std::string& name,
 			full_path += FileSystem::file_separator();
 			full_path += relative_path;
 
-			progress(relative_path, state++);
+			progress(format_l(_("Sending metadata for %s"), relative_path), state++);
 
 			FileRead fr;
 			fr.open(*g_fs, full_path);
@@ -817,6 +917,7 @@ void NetAddons::upload_addon(const std::string& name,
 
 	// Phase 2: The server tells us which files to send.
 
+	SDL_Delay(10 * state);  // Give the server some time to process large data batches.
 	int64_t nr_files_to_send = math::to_int(read_line());
 	state = 0;
 	progress("", state);
@@ -833,11 +934,10 @@ void NetAddons::upload_addon(const std::string& name,
 		std::string relative_path = pair.first;
 		relative_path += FileSystem::file_separator();
 		relative_path += pair.second;
-		progress(relative_path, state++);
+		progress(format_l(_("Uploading %s"), relative_path), state++);
 
 		const auto& data = file_contents.at(pair);
 		write_to_server(data.second.get(), data.first);
-		SDL_Delay(100);  // Give the send buffer time to clear up
 	}
 	progress("", state);
 	write_to_server("ENDOFSTREAM\n");
@@ -851,10 +951,10 @@ void NetAddons::upload_screenshot(const std::string& addon,
                                   const std::string& description) {
 	check_string_validity(addon);
 	if (contains(description, "\n")) {
-		throw WLWarning("", "Screenshot descriptions may not contain newlines");
+		throw_warning("Screenshot descriptions may not contain newlines");
 	}
 	init();
-	CrashGuard guard(*this);
+	CrashGuard guard(*this, true);
 
 	std::string send = kCmdSubmitScreenshot;
 	send += ' ';
@@ -888,7 +988,7 @@ std::string NetAddons::download_screenshot(const std::string& name, const std::s
 	try {
 		check_string_validity(name);
 		init();
-		CrashGuard guard(*this);
+		CrashGuard guard(*this, false);
 
 		std::string send = kCmdScreenshot;
 		send += ' ';
@@ -919,7 +1019,7 @@ std::string NetAddons::download_screenshot(const std::string& name, const std::s
 
 void NetAddons::contact(const std::string& enquiry) {
 	init();
-	CrashGuard guard(*this);
+	CrashGuard guard(*this, false);
 
 	std::string send = kCmdContact;
 	append_multiline_message(send, enquiry);
