@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2022 by the Widelands Development Team
+ * Copyright (C) 2004-2025 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,10 +25,12 @@
 
 #include "network/network.h"
 
-#define LAN_PROMOTION_PROTOCOL_VERSION 1
+constexpr uint8_t kLanPromotionProtocolVersion = 1;
 
-#define LAN_GAME_CLOSED 0
-#define LAN_GAME_OPEN 1
+enum {
+	kLanGameClosed = 0,
+	kLanGameOpen = 1,
+};
 
 struct NetGameInfo {
 	char magic[6];
@@ -133,7 +135,7 @@ private:
 	void close_socket(asio::ip::udp::socket* socket);
 
 	/// No idea what this does. I think it is only really used when asynchronous operations are done.
-	asio::io_service io_service;
+	asio::io_context io_context;
 	/// The socket for IPv4.
 	asio::ip::udp::socket socket_v4;
 	/// The socket for IPv6.
@@ -179,7 +181,8 @@ struct LanGameFinder : LanBase {
 private:
 	std::list<std::unique_ptr<NetOpenGame>> opengames;
 
-	void (*callback)(int32_t, const NetOpenGame* const, void*);
+	void (*callback)(int32_t, const NetOpenGame* const, void*)  // linebreak to make codecheck happy
+	   {nullptr};
 	void* userdata;
 };
 
