@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2024 by the Widelands Development Team
+ * Copyright (C) 2002-2025 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -185,6 +185,9 @@ void MultilineTextarea::draw(RenderTarget& dst) {
 		break;
 	case UI::Align::kLeft:
 		anchor = kRichtextMargin;
+		break;
+	default:
+		NEVER_HERE();
 	}
 	render_anchor_ = Vector2i(anchor, 0);
 	rendered_text_->draw(dst, render_anchor_,
