@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2024 by the Widelands Development Team
+ * Copyright (C) 2002-2025 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -181,7 +181,6 @@ LaunchGame::LaunchGame(MenuCapsule& fsmm,
      settings_(settings),
      ctrl_(ctrl),
      has_desyncing_addon_(false) {
-	warn_desyncing_addon_.set_visible(false);
 	write_replay_.set_state(true);
 
 	win_condition_dropdown_.selected.connect([this]() { win_condition_selected(); });
@@ -284,6 +283,7 @@ bool LaunchGame::should_write_replay() const {
 }
 
 void LaunchGame::update_advanced_options() {
+	i18n::Textdomain td("widelands");
 	const bool show = toggle_advanced_options_.style() == UI::Button::VisualState::kPermpressed;
 	advanced_options_box_.set_visible(show);
 	toggle_advanced_options_.set_title(show ? _("Show fewer options") : _("Show more options"));
@@ -291,6 +291,7 @@ void LaunchGame::update_advanced_options() {
 }
 
 void LaunchGame::update_peaceful_mode() {
+	i18n::Textdomain td("widelands");
 	UI::Checkbox* checkbox = game_flag_checkboxes_.at(GameSettings::Flags::kPeaceful).first;
 	bool forbidden =
 	   peaceful_mode_forbidden_ || settings_.settings().scenario || settings_.settings().savegame;
@@ -312,6 +313,7 @@ void LaunchGame::update_peaceful_mode() {
 }
 
 void LaunchGame::update_custom_starting_positions() {
+	i18n::Textdomain td("widelands");
 	UI::Checkbox* checkbox =
 	   game_flag_checkboxes_.at(GameSettings::Flags::kCustomStartingPositions).first;
 	const GameSettings& settings = settings_.settings();
@@ -353,6 +355,7 @@ void LaunchGame::update_custom_starting_positions() {
 }
 
 void LaunchGame::update_fogless() {
+	i18n::Textdomain td("widelands");
 	UI::Checkbox* checkbox = game_flag_checkboxes_.at(GameSettings::Flags::kFogless).first;
 	const GameSettings& settings = settings_.settings();
 	const bool forbidden = settings.scenario || settings.savegame;
@@ -376,6 +379,7 @@ void LaunchGame::update_fogless() {
 }
 
 void LaunchGame::update_naval_warfare() {
+	i18n::Textdomain td("widelands");
 	UI::Checkbox* checkbox = game_flag_checkboxes_.at(GameSettings::Flags::kAllowNavalWarfare).first;
 	const GameSettings& settings = settings_.settings();
 	const bool forbidden = settings.scenario || settings.savegame || !map_is_seafaring_;
@@ -403,6 +407,7 @@ void LaunchGame::update_naval_warfare() {
 }
 
 void LaunchGame::update_forbid_diplomacy() {
+	i18n::Textdomain td("widelands");
 	UI::Checkbox* checkbox = game_flag_checkboxes_.at(GameSettings::Flags::kForbidDiplomacy).first;
 	const GameSettings& settings = settings_.settings();
 	const bool forbidden = settings.scenario || settings.savegame;
@@ -426,6 +431,7 @@ void LaunchGame::update_forbid_diplomacy() {
 }
 
 bool LaunchGame::init_win_condition_label() {
+	i18n::Textdomain td("widelands");
 	win_condition_duration_.set_visible(false);
 	if (settings_.settings().scenario) {
 		win_condition_dropdown_.set_enabled(false);
