@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2024 by the Widelands Development Team
+ * Copyright (C) 2010-2025 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +23,8 @@
 #include "graphic/text_layout.h"
 #include "logic/player.h"
 #include "wlapplication_mousewheel_options.h"
-#include "wui/interactive_base.h"
+#include "wui/actionconfirm.h"
+#include "wui/interactive_player.h"
 
 constexpr int8_t kButtonSize = 25;
 
@@ -95,7 +96,8 @@ InputQueueDisplay::InputQueueDisplay(UI::Panel* parent,
                                      Widelands::InputQueue& queue,
                                      bool show_only,
                                      bool has_priority,
-                                     BuildingWindow::CollapsedState* collapsed)
+                                     BuildingWindow::CollapsedState* collapsed,
+                                     uint32_t disambiguator_id)
    : InputQueueDisplay(parent,
                        interactive_base,
                        building,
@@ -105,14 +107,16 @@ InputQueueDisplay::InputQueueDisplay(UI::Panel* parent,
                        nullptr,
                        show_only,
                        has_priority,
-                       collapsed) {
+                       collapsed,
+                       disambiguator_id) {
 }
 InputQueueDisplay::InputQueueDisplay(UI::Panel* parent,
                                      InteractiveBase& interactive_base,
                                      Widelands::ConstructionSite& constructionsite,
                                      Widelands::WareWorker type,
                                      Widelands::DescriptionIndex ware_or_worker_index,
-                                     BuildingWindow::CollapsedState* collapsed)
+                                     BuildingWindow::CollapsedState* collapsed,
+                                     uint32_t disambiguator_id)
    : InputQueueDisplay(
         parent,
         interactive_base,
@@ -123,7 +127,8 @@ InputQueueDisplay::InputQueueDisplay(UI::Panel* parent,
         dynamic_cast<Widelands::ProductionsiteSettings*>(constructionsite.get_settings()),
         false,
         true,
-        collapsed) {
+        collapsed,
+        disambiguator_id) {
 }
 
 static inline std::string create_tooltip(const bool increase) {
@@ -162,7 +167,8 @@ InputQueueDisplay::InputQueueDisplay(UI::Panel* parent,
                                      Widelands::ProductionsiteSettings* settings,
                                      bool show_only,
                                      bool has_priority,
-                                     BuildingWindow::CollapsedState* collapsed)
+                                     BuildingWindow::CollapsedState* collapsed,
+                                     uint32_t disambiguator_id)
    : UI::Box(parent,
              UI::PanelStyle::kWui,
              format("inputqueuedisplay_%u_%u", static_cast<unsigned>(type), ware_or_worker_index),
@@ -178,6 +184,7 @@ InputQueueDisplay::InputQueueDisplay(UI::Panel* parent,
      index_(ware_or_worker_index),
      queue_(queue),
      settings_(settings),
+     disambiguator_id_(disambiguator_id),
      max_fill_indicator_(*g_image_cache->get("images/wui/buildings/max_fill_indicator.png")),
      vbox_(this, UI::PanelStyle::kWui, "vbox", 0, 0, UI::Box::Vertical),
      hbox_(&vbox_, UI::PanelStyle::kWui, "hbox", 0, 0, UI::Box::Horizontal),
@@ -234,10 +241,11 @@ InputQueueDisplay::InputQueueDisplay(UI::Panel* parent,
                kButtonSize,
                0,
                4,
-               has_priority_ ? priority_to_index(settings_ != nullptr ?
-                                                    settings_->ware_queues.at(index_).priority :
-                                                    building.get_priority(type_, index_)) :
-                               2,
+               has_priority_ ?
+                  priority_to_index(settings_ != nullptr ?
+                                       settings_->ware_queues.at(index_).priority :
+                                       building.get_priority(type_, index_, disambiguator_id_)) :
+                  2,
                UI::SliderStyle::kWuiLight,
                "",
                kButtonSize,
@@ -250,7 +258,14 @@ InputQueueDisplay::InputQueueDisplay(UI::Panel* parent,
      nr_icons_(queue_ != nullptr            ? queue_->get_max_size() :
                type_ == Widelands::wwWORKER ? settings_->worker_queues.at(index_).max_fill :
                                               settings_->ware_queues.at(index_).max_fill),
+     max_icons_(nr_icons_),
      icons_(nr_icons_, nullptr),
+     total_fill_(&hbox_,
+                 UI::PanelStyle::kWui,
+                 "total_fill",
+                 UI::FontStyle::kWuiLabel,
+                 std::string(),
+                 UI::Align::kRight),
      fill_index_under_mouse_(-1) {
 
 	assert((queue_ == nullptr) ^ (settings_ == nullptr));
@@ -280,10 +295,10 @@ InputQueueDisplay::InputQueueDisplay(UI::Panel* parent,
 		                                building.owner().tribe().get_worker_descr(index_)->icon());
 		hbox_.add(icons_[i]);
 	}
-
 	hbox_.add_inf_space();
 	hbox_.add(&b_increase_desired_fill_);
 	hbox_.add(&b_increase_real_fill_);
+	hbox_.add(&total_fill_, UI::Box::Resizing::kAlign, UI::Align::kCenter);
 
 	priority_.set_cursor_fixed_height(kButtonSize * 2 / 3);
 
@@ -365,6 +380,29 @@ InputQueueDisplay::InputQueueDisplay(UI::Panel* parent,
 	// Do not call think() yet, it might deadlock
 }
 
+void InputQueueDisplay::unlock_desired_fill(bool call_unlock_fn) {
+	if (call_unlock_fn) {
+		unlock_fn_();
+	}
+
+	lock_desired_fill_ = false;
+	b_decrease_desired_fill_.set_tooltip(create_tooltip(false));
+	b_increase_desired_fill_.set_tooltip(create_tooltip(true));
+}
+
+void InputQueueDisplay::lock_desired_fill(const std::string& reason,
+                                          const std::string& unlock_title,
+                                          const std::string& unlock_body,
+                                          std::function<void()> unlock_fn) {
+	lock_desired_fill_ = true;
+	unlock_fn_ = unlock_fn;
+	unlock_title_ = unlock_title;
+	unlock_body_ = unlock_body;
+
+	b_decrease_desired_fill_.set_tooltip(reason);
+	b_increase_desired_fill_.set_tooltip(reason);
+}
+
 void InputQueueDisplay::recurse(const std::function<void(InputQueueDisplay&)>& functor) {
 	for (UI::Panel* p = get_parent()->get_first_child(); p != nullptr; p = p->get_next_sibling()) {
 		if (upcast(InputQueueDisplay, i, p)) {
@@ -407,6 +445,13 @@ bool InputQueueDisplay::handle_mousemove(
 	return true;
 }
 
+void InputQueueDisplay::handle_mousein(bool inside) {
+	if (!inside) {
+		fill_index_under_mouse_ = -1;
+	}
+	UI::Box::handle_mousein(inside);
+}
+
 bool InputQueueDisplay::handle_mousewheel(int32_t x, int32_t y, uint16_t modstate) {
 	if (show_only_ || !can_act_) {
 		return false;
@@ -476,15 +521,17 @@ void InputQueueDisplay::set_priority(const Widelands::WarePriority& priority) {
 	}
 
 	if (!can_act_ || !has_priority_ ||
-	    priority == (queue_ != nullptr ? b->get_priority(type_, index_) : get_setting()->priority)) {
+	    priority == (queue_ != nullptr ? b->get_priority(type_, index_, disambiguator_id_) :
+	                                     get_setting()->priority)) {
 		return;
 	}
 
 	if (Widelands::Game* game = ibase_.get_game()) {
-		game->send_player_set_ware_priority(*b, type_, index_, priority, settings_ != nullptr);
+		game->send_player_set_ware_priority(
+		   *b, type_, index_, priority, settings_ != nullptr, disambiguator_id_);
 	} else {
 		if (queue_ != nullptr) {
-			b->set_priority(type_, index_, priority);
+			b->set_priority(type_, index_, priority, disambiguator_id_);
 		} else {
 			get_setting()->priority = priority;
 		}
@@ -499,6 +546,21 @@ void InputQueueDisplay::clicked_desired_fill(const int8_t delta) {
 		return;
 	}
 
+	const bool ctrl_down = (SDL_GetModState() & KMOD_CTRL) != 0;
+
+	if (lock_desired_fill_) {
+		if (!ctrl_down) {
+			upcast(InteractivePlayer, ipl, &ibase_);
+			assert(ipl != nullptr);
+			show_generic_callback_confirm(*ipl, b, unlock_title_, unlock_body_, [this, delta]() {
+				unlock_desired_fill(true);
+				clicked_desired_fill(delta);
+			});
+			return;
+		}
+		unlock_desired_fill(true);
+	}
+
 	const unsigned desired_fill =
 	   queue_ != nullptr ? queue_->get_max_fill() : get_setting()->desired_fill;
 	const unsigned max_fill = queue_ != nullptr ? queue_->get_max_size() : get_setting()->max_fill;
@@ -508,11 +570,11 @@ void InputQueueDisplay::clicked_desired_fill(const int8_t delta) {
 		return;
 	}
 
-	const bool ctrl_down = (SDL_GetModState() & KMOD_CTRL) != 0;
 	const unsigned new_fill = ctrl_down ? delta < 0 ? 0 : max_fill : desired_fill + delta;
 
 	if (Widelands::Game* game = ibase_.get_game()) {
-		game->send_player_set_input_max_fill(*b, index_, type_, new_fill, settings_ != nullptr);
+		game->send_player_set_input_max_fill(
+		   *b, index_, type_, new_fill, settings_ != nullptr, disambiguator_id_);
 	} else {
 		if (queue_ != nullptr) {
 			queue_->set_max_fill(new_fill);
@@ -526,12 +588,27 @@ void InputQueueDisplay::change_desired_fill(const int8_t delta) {
 	if (delta == 0) {
 		return;
 	}
+
 	MutexLock m(MutexLock::ID::kObjects);
 	Widelands::Building* b = building_.get(ibase_.egbase());
 	if (b == nullptr) {
 		return;
 	}
 
+	if (lock_desired_fill_) {
+		const bool ctrl_down = (SDL_GetModState() & KMOD_CTRL) != 0;
+		if (!ctrl_down) {
+			upcast(InteractivePlayer, ipl, &ibase_);
+			assert(ipl != nullptr);
+			show_generic_callback_confirm(*ipl, b, unlock_title_, unlock_body_, [this, delta]() {
+				unlock_desired_fill(true);
+				change_desired_fill(delta);
+			});
+			return;
+		}
+		unlock_desired_fill(true);
+	}
+
 	unsigned desired_fill = queue_ != nullptr ? queue_->get_max_fill() : get_setting()->desired_fill;
 	const unsigned max_fill = queue_ != nullptr ? queue_->get_max_size() : get_setting()->max_fill;
 	assert(desired_fill <= max_fill);
@@ -550,7 +627,8 @@ void InputQueueDisplay::change_desired_fill(const int8_t delta) {
 	}
 
 	if (Widelands::Game* game = ibase_.get_game()) {
-		game->send_player_set_input_max_fill(*b, index_, type_, desired_fill, settings_ != nullptr);
+		game->send_player_set_input_max_fill(
+		   *b, index_, type_, desired_fill, settings_ != nullptr, disambiguator_id_);
 	} else {
 		if (queue_ != nullptr) {
 			queue_->set_max_fill(desired_fill);
@@ -567,6 +645,20 @@ void InputQueueDisplay::set_desired_fill(unsigned new_fill) {
 		return;
 	}
 
+	if (lock_desired_fill_) {
+		const bool ctrl_down = (SDL_GetModState() & KMOD_CTRL) != 0;
+		if (!ctrl_down) {
+			upcast(InteractivePlayer, ipl, &ibase_);
+			assert(ipl != nullptr);
+			show_generic_callback_confirm(*ipl, b, unlock_title_, unlock_body_, [this, new_fill]() {
+				unlock_desired_fill(true);
+				set_desired_fill(new_fill);
+			});
+			return;
+		}
+		unlock_desired_fill(true);
+	}
+
 	const unsigned desired_fill =
 	   queue_ != nullptr ? queue_->get_max_fill() : get_setting()->desired_fill;
 	const unsigned max_fill = queue_ != nullptr ? queue_->get_max_size() : get_setting()->max_fill;
@@ -578,7 +670,8 @@ void InputQueueDisplay::set_desired_fill(unsigned new_fill) {
 	}
 
 	if (Widelands::Game* game = ibase_.get_game()) {
-		game->send_player_set_input_max_fill(*b, index_, type_, new_fill, settings_ != nullptr);
+		game->send_player_set_input_max_fill(
+		   *b, index_, type_, new_fill, settings_ != nullptr, disambiguator_id_);
 	} else {
 		if (queue_ != nullptr) {
 			queue_->set_max_fill(new_fill);
@@ -629,6 +722,10 @@ InputQueueDisplay::get_setting() const {
 	                              nullptr;
 }
 
+void InputQueueDisplay::set_max_icons(size_t m) {
+	max_icons_ = m;
+}
+
 static const RGBAColor kColorComing(127, 127, 127, 191);
 static const RGBAColor kColorMissing(191, 191, 191, 127);
 
@@ -665,14 +762,17 @@ void InputQueueDisplay::think() {
 	assert(max_fill <= nr_icons_);
 
 	for (unsigned i = 0; i < nr_icons_; ++i) {
-		icons_[i]->set_visible(i < max_fill);
+		icons_[i]->set_visible(i < max_fill && i < max_icons_);
 		icons_[i]->set_grey_out(i >= real_fill);
 		icons_[i]->set_grey_out_color(i < real_fill + nr_coming ? kColorComing : kColorMissing);
 	}
+	total_fill_.set_text(max_fill > max_icons_ ? format_l(_("+%u"), max_fill - max_icons_) :
+	                                             std::string());
 
 	if (has_priority_) {
-		const Widelands::WarePriority& p =                                     // NOLINT
-		   queue_ ? b->get_priority(type_, index_) : get_setting()->priority;  // NOLINT
+		const Widelands::WarePriority& p = queue_ != nullptr ?  // NOLINT
+		                                      b->get_priority(type_, index_, disambiguator_id_) :
+		                                      get_setting()->priority;
 		// The purpose of this check is to prevent the slider from snapping back directly after
 		// the user dragged it, because the playercommand is not executed immediately of course
 		if ((slider_was_moved_ == nullptr) || *slider_was_moved_ == p) {
@@ -731,19 +831,20 @@ void InputQueueDisplay::draw_overlay(RenderTarget& r) {
 		                 (icons_[0]->get_h() - max_fill_indicator_.height()) / 2;
 		r.blit(Vector2i(calc_xpos(desired_fill), ypos), &max_fill_indicator_);
 
-		if (can_act_ && fill_index_under_mouse_ >= 0) {
+		if (can_act_ && fill_index_under_mouse_ >= 0 &&
+		    (!lock_desired_fill_ || (SDL_GetModState() & KMOD_CTRL) != 0)) {
 			r.blitrect_scale(Rectf(calc_xpos(fill_index_under_mouse_), ypos,
 			                       max_fill_indicator_.width(), max_fill_indicator_.height()),
-			                 &max_fill_indicator_,
-			                 Recti(0, 0, max_fill_indicator_.width(), max_fill_indicator_.height()),
-			                 0.4f, BlendMode::Default);
+			                 &max_fill_indicator_, max_fill_indicator_.rect(), 0.4f,
+			                 BlendMode::Default);
 		}
 	}
 
 	// Draw priority indicator
 	if (has_priority_ && is_collapsed()) {
-		const size_t p = priority_to_index(queue_ != nullptr ? b->get_priority(type_, index_) :
-		                                                       get_setting()->priority);
+		const size_t p =
+		   priority_to_index(queue_ != nullptr ? b->get_priority(type_, index_, disambiguator_id_) :
+		                                         get_setting()->priority);
 		const int w = priority_indicator_.get_w();
 		// Add kButtonSize / 4 to the position to align it against the collapse button
 		const int x = hbox_.get_x() + priority_indicator_.get_x() + kButtonSize / 4;
